``pygcam.scenarioSetup``
==========================

The :ref:`setup <setup>` sub-command reads instructions from a
:doc:`scenarios-xml` file or runs a Python script to create the XML
input files necessary to run a project's scenarios. See
:doc:`setup` for more information.

API
---

.. automodule:: pygcam.scenarioSetup
   :members:

